@@ -5,10 +5,24 @@
 # It is distributed under the GNU General Public License.
 # See the file COPYING for details.
 #
-# (c) 1997-2015 Gerd Neugebauer
+# (c) 1997-2020 Gerd Neugebauer
 #
 # Net: gene@gerd-neugebauer.de
 #
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+#
 #*****************************************************************************
 
 foreach $_ (@ARGV)
@@ -108,6 +122,7 @@ sub analyze_file
 	  s/\\_//go;
 	  if ( $head{$name} eq '' ) { $n = "\\Mac{$name}"; }
 	  else { $n = $head{$name}; }
+	  $n =~ s/([^\\])_/$1\\_/g;
 	  print "\\begin{Macro}{$n}{$_}\n  \\begin{Arguments}";
 	  foreach $a (@a)
 	  { print "\n    & \\Var{$a} & $arg{$a}\\\\";
@@ -217,6 +232,7 @@ sub analyze_file
 	$t = $1;
 	$c = $3;
 	s/_/\\_/go;
+	$t =~ s/_/\\_/g;
 	print "$NL    $t\\ \t&\\Member{$_};\t& $c";
 	$NL = "\\\\\n";
       } elsif ( /^[ {]*([a-zA-Z_][^(]*[^a-zA-Z0-9_(])([a-zA-Z0-9_]+);/o )
